==> v0.15.6.tar.gz: ambient-local-exporter/pkg/provider/awn/types.go <==
package awn

type AmbientWeatherUpdate struct {
	PassKey        *string  `json:"PASSKEY,omitempty" schema:"PASSKEY"`
	StationType    *string  `json:"stationtype,omitempty" schema:"stationtype"`
	DateUTC        *string  `json:"dateutc,omitempty" schema:"dateutc"`
	TempF          *float64 `json:"tempf,omitempty" schema:"tempf"`
	Humidity       *int     `json:"humidity,omitempty" schema:"humidity"`
	WindSpeedMPH   *float64 `json:"windspeedmph,omitempty" schema:"windspeedmph"`
	WindGustMPH    *float64 `json:"windgustmph,omitempty" schema:"windgustmph"`
	MaxDailyGust   *float64 `json:"maxdailygust,omitempty" schema:"maxdailygust"`
	WindDir        *int     `json:"winddir,omitempty" schema:"winddir"`
	WindDirAVG10m  *int     `json:"winddir_avg10m,omitempty" schema:"winddir_avg10m"`
	UV             *int     `json:"uv,omitempty" schema:"uv"`
	SolarRadiation *float64 `json:"solarradiation,omitempty" schema:"solarradiation"`
	HourlyRainIn   *float64 `json:"hourlyrainin,omitempty" schema:"hourlyrainin"`
	EventRainIn    *float64 `json:"eventrainin,omitempty" schema:"eventrainin"`
	DailyRainIn    *float64 `json:"dailyrainin,omitempty" schema:"dailyrainin"`
	WeeklyRainIn   *float64 `json:"weeklyrainin,omitempty" schema:"weeklyrainin"`
	MonthlyRainIn  *float64 `json:"monthlyrainin,omitempty" schema:"monthlyrainin"`
	YearlyRainIn   *float64 `json:"yearlyrainin,omitempty" schema:"yearlyrainin"`
	TotalRainIn    *float64 `json:"totalrainin,omitempty" schema:"totalrainin"`
	BattOut        *int     `json:"battout,omitempty" schema:"battout"`
	BattRain       *int     `json:"battrain,omitempty" schema:"battrain"`
	TempInF        *float64 `json:"tempinf,omitempty" schema:"tempinf"`
	HumidityIn     *int     `json:"humidityin,omitempty" schema:"humidityin"`
	BaromRelIn     *float64 `json:"baromrelin,omitempty" schema:"baromrelin"`
	BaromAbsIn     *float64 `json:"baromabsin,omitempty" schema:"baromabsin"`
	BattIn         *int     `json:"battin,omitempty" schema:"battin"`
	BattCO2        *int     `json:"batt_co2,omitempty" schema:"batt_co2"`
	*AmbientTempHumiditySensors
	*AmbientLightningData
}

type AmbientLightningData struct {
	BattLightning     *int `json:"batt_lightning,omitempty" schema:"batt_lightning"`
	LightningDay      *int `json:"lightning_day,omitempty" schema:"lightning_day" description:"count of lightning detections"`
	LightningDistance *int `json:"lightning_distance,omitempty" schema:"lightning_distance" description:"distance in kilometers"`
	LightningTime     *int `json:"lightningTime,omitempty" schema:"lightningTime" description:"last lightning detection time"`
}

type AmbientTempHumiditySensors struct {
	Temp1F    *float64 `json:"temp1f,omitempty" schema:"temp1f"`
	Temp2F    *float64 `json:"temp2f,omitempty" schema:"temp2f"`
	Temp3F    *float64 `json:"temp3f,omitempty" schema:"temp3f"`
	Temp4F    *float64 `json:"temp4f,omitempty" schema:"temp4f"`
	Temp5F    *float64 `json:"temp5f,omitempty" schema:"temp5f"`
	Temp6F    *float64 `json:"temp6f,omitempty" schema:"temp6f"`
	Temp7F    *float64 `json:"temp7f,omitempty" schema:"temp7f"`
	Temp8F    *float64 `json:"temp8f,omitempty" schema:"temp8f"`
	Humidity1 *int     `json:"humidity1,omitempty" schema:"humidity1"`
	Humidity2 *int     `json:"humidity2,omitempty" schema:"humidity2"`
	Humidity3 *int     `json:"humidity3,omitempty" schema:"humidity3"`
	Humidity4 *int     `json:"humidity4,omitempty" schema:"humidity4"`
	Humidity5 *int     `json:"humidity5,omitempty" schema:"humidity5"`
	Humidity6 *int     `json:"humidity6,omitempty" schema:"humidity6"`
	Humidity7 *int     `json:"humidity7,omitempty" schema:"humidity7"`
	Humidity8 *int     `json:"humidity8,omitempty" schema:"humidity8"`
	Batt1     *int     `json:"batt1,omitempty" schema:"batt1"`
	Batt2     *int     `json:"batt2,omitempty" schema:"batt2"`
	Batt3     *int     `json:"batt3,omitempty" schema:"batt3"`
	Batt4     *int     `json:"batt4,omitempty" schema:"batt4"`
	Batt5     *int     `json:"batt5,omitempty" schema:"batt5"`
	Batt6     *int     `json:"batt6,omitempty" schema:"batt6"`
	Batt7     *int     `json:"batt7,omitempty" schema:"batt7"`
	Batt8     *int     `json:"batt8,omitempty" schema:"batt8"`
}

==> v0.18.2.tar.gz: ambient-local-exporter/pkg/provider/awn/types.go <==
package awn

type AmbientWeatherUpdate struct {
	PassKey        *string  `json:"PASSKEY,omitempty" schema:"PASSKEY"`
	StationType    *string  `json:"stationtype,omitempty" schema:"stationtype"`
	DateUTC        *string  `json:"dateutc,omitempty" schema:"dateutc"`
	TempF          *float64 `json:"tempf,omitempty" schema:"tempf"`
	Humidity       *int     `json:"humidity,omitempty" schema:"humidity"`
	WindSpeedMPH   *float64 `json:"windspeedmph,omitempty" schema:"windspeedmph"`
	WindGustMPH    *float64 `json:"windgustmph,omitempty" schema:"windgustmph"`
	MaxDailyGust   *float64 `json:"maxdailygust,omitempty" schema:"maxdailygust"`
	WindDir        *int     `json:"winddir,omitempty" schema:"winddir"`
	WindDirAVG10m  *int     `json:"winddir_avg10m,omitempty" schema:"winddir_avg10m"`
	UV             *int     `json:"uv,omitempty" schema:"uv"`
	SolarRadiation *float64 `json:"solarradiation,omitempty" schema:"solarradiation"`
	HourlyRainIn   *float64 `json:"hourlyrainin,omitempty" schema:"hourlyrainin"`
	EventRainIn    *float64 `json:"eventrainin,omitempty" schema:"eventrainin"`
	DailyRainIn    *float64 `json:"dailyrainin,omitempty" schema:"dailyrainin"`
	WeeklyRainIn   *float64 `json:"weeklyrainin,omitempty" schema:"weeklyrainin"`
	MonthlyRainIn  *float64 `json:"monthlyrainin,omitempty" schema:"monthlyrainin"`
	YearlyRainIn   *float64 `json:"yearlyrainin,omitempty" schema:"yearlyrainin"`
	TotalRainIn    *float64 `json:"totalrainin,omitempty" schema:"totalrainin"`
	BattOut        *int     `json:"battout,omitempty" schema:"battout"`
	BattRain       *int     `json:"battrain,omitempty" schema:"battrain"`
	TempInF        *float64 `json:"tempinf,omitempty" schema:"tempinf"`
	HumidityIn     *int     `json:"humidityin,omitempty" schema:"humidityin"`
	BaromRelIn     *float64 `json:"baromrelin,omitempty" schema:"baromrelin"`
	BaromAbsIn     *float64 `json:"baromabsin,omitempty" schema:"baromabsin"`
	BattIn         *int     `json:"battin,omitempty" schema:"battin"`
	BattCO2        *int     `json:"batt_co2,omitempty" schema:"batt_co2"`
	*AmbientTempHumiditySensors
	*AmbientLightningData
}

type AmbientLightningData struct {
	BattLightning     *int `json:"batt_lightning,omitempty" schema:"batt_lightning"`
	LightningDay      *int `json:"lightning_day,omitempty" schema:"lightning_day" description:"count of lightning detections"`
	LightningDistance *int `json:"lightning_distance,omitempty" schema:"lightning_distance" description:"distance in kilometers"`
	LightningLastTime *int `json:"lightning_time,omitempty" schema:"lightning_time" description:"last lightning detection time"`
}

type AmbientTempHumiditySensors struct {
	Temp1F    *float64 `json:"temp1f,omitempty" schema:"temp1f"`
	Temp2F    *float64 `json:"temp2f,omitempty" schema:"temp2f"`
	Temp3F    *float64 `json:"temp3f,omitempty" schema:"temp3f"`
	Temp4F    *float64 `json:"temp4f,omitempty" schema:"temp4f"`
	Temp5F    *float64 `json:"temp5f,omitempty" schema:"temp5f"`
	Temp6F    *float64 `json:"temp6f,omitempty" schema:"temp6f"`
	Temp7F    *float64 `json:"temp7f,omitempty" schema:"temp7f"`
	Temp8F    *float64 `json:"temp8f,omitempty" schema:"temp8f"`
	Humidity1 *int     `json:"humidity1,omitempty" schema:"humidity1"`
	Humidity2 *int     `json:"humidity2,omitempty" schema:"humidity2"`
	Humidity3 *int     `json:"humidity3,omitempty" schema:"humidity3"`
	Humidity4 *int     `json:"humidity4,omitempty" schema:"humidity4"`
	Humidity5 *int     `json:"humidity5,omitempty" schema:"humidity5"`
	Humidity6 *int     `json:"humidity6,omitempty" schema:"humidity6"`
	Humidity7 *int     `json:"humidity7,omitempty" schema:"humidity7"`
	Humidity8 *int     `json:"humidity8,omitempty" schema:"humidity8"`
	Batt1     *int     `json:"batt1,omitempty" schema:"batt1"`
	Batt2     *int     `json:"batt2,omitempty" schema:"batt2"`
	Batt3     *int     `json:"batt3,omitempty" schema:"batt3"`
	Batt4     *int     `json:"batt4,omitempty" schema:"batt4"`
	Batt5     *int     `json:"batt5,omitempty" schema:"batt5"`
	Batt6     *int     `json:"batt6,omitempty" schema:"batt6"`
	Batt7     *int     `json:"batt7,omitempty" schema:"batt7"`
	Batt8     *int     `json:"batt8,omitempty" schema:"batt8"`
}
